#!/usr/bin/env python
""" MultiQC hook functions - we tie into the MultiQC
core here to add in extra functionality. """

import logging
from multiqc.utils import report, config
from collections import OrderedDict

log = logging.getLogger('multiqc')

def after_modules():
    """ Plugin code to run when MultiQC modules have completed  """
    config_data = getattr(config, "multiqc_cgs", {})
    namespace_map = {}
    for index, data in enumerate(report.general_stats_headers):
        if len(data) > 0:
            namespace_map[list(data.items())[0][1]['namespace']] = index
    if config_data:
        for data_namespace in config_data:
            added_entries = []
            for field in config_data[data_namespace]:
                entry = {'namespace': data_namespace}
                for key in config_data[data_namespace][field]:
                    entry[key] = config_data[data_namespace][field][key]
                if 'title' not in entry:
                    entry['title'] = field
                if 'min' not in entry:
                    entry['min'] = 0
                if 'format' not in entry:
                    entry['format'] = '{:,.1f}'
                added_entries.append((field, entry))
            log.debug("Adding extra columns to general statistics: {}".format(added_entries))
            report.general_stats_headers[namespace_map[data_namespace]] = OrderedDict( list(report.general_stats_headers[namespace_map[data_namespace]].items()) + added_entries)



#!/usr/bin/env python
"""
hook that make it possible to modify general statistics table
"""

from setuptools import setup, find_packages

version = '0.1'

setup(
    name = 'multiqc_cgs',
    version = version,
    author = 'Patrik Smeds',
    author_email = 'patrik.smeds@scilifelab.uu.se',
    description = "make it possible to add more information to general statisticsn",
    long_description = __doc__,
    keywords = 'bioinformatics',
    url = '',
    download_url = '',
    license = 'GPL3',
    packages = find_packages(),
    include_package_data = True,
    install_requires = [
        'multiqc'
    ],
    entry_points = {
        'multiqc.hooks.v1': [
            'after_modules = multiqc_cgs.hooks:after_modules'
        ]
    },
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Environment :: Web Environment',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: JavaScript',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Visualization',
    ],
)
